import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/sumitradevipolina/11be5165425884993b535e49dd475953/raw/2c55a6019ebac42c1dd92ddc642055f74b999b0c/iris.csv', // URL File link which we got from raw iris dataset
].join(''); // we use this join to create a style sheet for our dataset by joing this through java script
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width; // These defines lenght and width of the sepal_lenght which is y-axis and petal_lenght which is x-axis 
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);   // These commands gives us the lenght width and height for the space where we can do plot 

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species; //we are storing the dataset column values separartely  into variables

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'setosa':
              return 'red';
            case 'versicolor':
              return 'yellow';
            default:
              return 'lightblue'; // We define in what color the selected species are going to be represented
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d), // The species we selected are ploted by using map()
                      
        }));
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 10,
      bottom: 120,
      left: 70, // Gives the names on X-axis and Y-axis and the lenght and width values of those X-axis and y-axis
    })
    .radius(8);
  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry)); //These defines the plotting circles and the radius of those circles
    svg.append("text")
        .attr("x",-300)
        .attr("y",20)
        .attr("font-size","14px")
        .attr("transform","rotate(-90)")
        .text("Sepal Length") //Used for adding the Y lable 
    svg.append("text")
        .attr("x",500)
        .attr("y",475)
        .attr("font-size","14px")
        .text("Petal Length") // for adding the X lable

  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000); //call function is used for plotting the visualization
};
main();

